Module formatters

Module formatters 

Output formatters for CLI commands.

Provides consistent formatting across all CLI commands for JSON, text, and pretty output modes.

Modules

json
JSON output formatting.
pretty
Pretty (human-readable) output formatting.
text
Plain text output formatting.

Functions

escape_display
Escapes a string for safe interpolation into hand-crafted Text/Pretty output lines.
escape_error_text
Makes s safe to print to a terminal or log sink that does not itself escape untrusted content.
format_output
Format data according to the specified output format.